==> fontawesome_iconpicker-2.0.0-rc1.tar.gz: fontawesome_iconpicker/README.md <==
CONTENTS OF THIS FILE
---------------------

 * Introduction
 * Requirements
 * Installation
 * Configuration
 * Maintainers


INTRODUCTION
------------

The Font Awesome Iconpicker module Integrates the Font Awesome Iconpicker with
Drupal.

 * For a full description of the module visit:
   https://www.drupal.org/project/fontawesome_iconpicker

 * To submit bug reports and feature suggestions, or to track changes visit:
   https://www.drupal.org/project/issues/fontawesome_iconpicker


REQUIREMENTS
------------

This module requires the following libraries:

 * Font Awesome Library - http://fontawesome.io
 * Font Awesome Iconpicker Library - https://itsjavi.com/fontawesome-iconpicker

Download the libraries and place them in the libraries folder.
After downloading and moving the files, you should see files in the following paths:
    - Font Awesome CSS - docroot/libraries/fontawesome/css/font-awesome.min.css
    - Iconpicker CSS -
      docroot/libraries/fontawesome-iconpicker/dist/css/fontawesome-iconpicker.
      min.css


INSTALLATION
------------

Install the Font Awesome Iconpicker module as you would normally install a contributed Drupal module. Visit https://www.drupal.org/node/1897420 for further information.


CONFIGURATION
-------------

    1. Navigate to Administration > Extend and enable the module.
    2. Font Awesome Iconpicker can be used on "Text (formatted)" fields or "Text
       (plain)" fields.
    3. After attaching either of the above fields to an entity, the user is
       able to use the "Fontawesome Icon Picker" widget for those fields under
       the "Manage form display" section. The same should be done for "Manage
       Display".
    4. Save configurations.


MAINTAINERS
-----------

 * Chris Weber (cosmicdreams) - https://www.drupal.org/u/cosmicdreams
 * Shibin Das (D34dMan) - https://www.drupal.org/u/d34dman

Supporting organizations:

 * Factorial GmbH - https://www.drupal.org/factorial-gmbh
 * Digitwings - https://www.drupal.org/digitwing

==> fontawesome_iconpicker-3.0.0-rc1.tar.gz: fontawesome_iconpicker/README.md <==
# CONTENTS OF THIS FILE


 * Introduction
 * Requirements
 * Installation
 * Configuration
 * Maintainers


# INTRODUCTION


This module Integrates the Font Awesome Iconpicker with Drupal.

 * For a full description of the module visit:
   https://www.drupal.org/project/fontawesome_iconpicker

 * To submit bug reports and feature suggestions, or to track changes visit:
   https://www.drupal.org/project/issues/fontawesome_iconpicker


# REQUIREMENTS


This module requires the following libraries:

 * Font Awesome Library - http://fontawesome.io
 * Vanilla icon picker Library - https://github.com/AppoloDev/vanilla-icon-picker

# INSTALLATION


## Composer Installaion

Following steps would download this module and the required library within your Drupal installation.

1. Run `composer require drupal/fontawesome_iconpicker ^3`

Install the Font Awesome Iconpicker module as you would normally install a contributed Drupal module.
Visit https://www.drupal.org/node/1897420 for further information.

# CONFIGURATION


    1. Navigate to Administration > Extend and enable the module.
    2. Font Awesome Iconpicker can be used on "Text (formatted)" fields or "Text
       (plain)" fields. Usage on "Text (plain)" is recommended.
    3. After attaching either of the above fields to an entity, the user is
       able to use the "Fontawesome Icon Picker" widget for those fields under
       the "Manage form display" section. The same should be done for "Manage
       Display".
    4. Save configurations.


# MAINTAINERS


 * Shibin Das (D34dMan) - https://www.drupal.org/u/d34dman

Supporting organizations:

 * Factorial GmbH - https://www.drupal.org/factorial-gmbh
 * Digitwings - https://www.drupal.org/digitwing
